==> zio-aws-ec2_2.12-6.20.78.3-sources.jar: zio/aws/ec2/model/ModifyPrivateDnsNameOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.InstanceId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyPrivateDnsNameOptionsRequest(
    instanceId: InstanceId,
    privateDnsHostnameType: Optional[zio.aws.ec2.model.HostnameType] =
      Optional.Absent,
    enableResourceNameDnsARecord: Optional[Boolean] = Optional.Absent,
    enableResourceNameDnsAAAARecord: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest = {
    import ModifyPrivateDnsNameOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest
      .builder()
      .instanceId(InstanceId.unwrap(instanceId): java.lang.String)
      .optionallyWith(privateDnsHostnameType.map(value => value.unwrap))(
        _.privateDnsHostnameType
      )
      .optionallyWith(
        enableResourceNameDnsARecord.map(value => value: java.lang.Boolean)
      )(_.enableResourceNameDnsARecord)
      .optionallyWith(
        enableResourceNameDnsAAAARecord.map(value => value: java.lang.Boolean)
      )(_.enableResourceNameDnsAAAARecord)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest.ReadOnly =
    zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest.wrap(buildAwsValue())
}
object ModifyPrivateDnsNameOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest =
      zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest(
        instanceId,
        privateDnsHostnameType.map(value => value),
        enableResourceNameDnsARecord.map(value => value),
        enableResourceNameDnsAAAARecord.map(value => value)
      )
    def instanceId: InstanceId
    def privateDnsHostnameType: Optional[zio.aws.ec2.model.HostnameType]
    def enableResourceNameDnsARecord: Optional[Boolean]
    def enableResourceNameDnsAAAARecord: Optional[Boolean]
    def getInstanceId: ZIO[Any, Nothing, InstanceId] = ZIO.succeed(instanceId)
    def getPrivateDnsHostnameType
        : ZIO[Any, AwsError, zio.aws.ec2.model.HostnameType] = AwsError
      .unwrapOptionField("privateDnsHostnameType", privateDnsHostnameType)
    def getEnableResourceNameDnsARecord: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "enableResourceNameDnsARecord",
        enableResourceNameDnsARecord
      )
    def getEnableResourceNameDnsAAAARecord: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "enableResourceNameDnsAAAARecord",
        enableResourceNameDnsAAAARecord
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest
  ) extends zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest.ReadOnly {
    override val instanceId: InstanceId =
      zio.aws.ec2.model.primitives.InstanceId(impl.instanceId())
    override val privateDnsHostnameType
        : Optional[zio.aws.ec2.model.HostnameType] = zio.aws.core.internal
      .optionalFromNullable(impl.privateDnsHostnameType())
      .map(value => zio.aws.ec2.model.HostnameType.wrap(value))
    override val enableResourceNameDnsARecord: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enableResourceNameDnsARecord())
        .map(value => value: Boolean)
    override val enableResourceNameDnsAAAARecord: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enableResourceNameDnsAAAARecord())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest
  ): zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.2-sources.jar: zio/aws/ec2/model/ModifyPrivateDnsNameOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.InstanceId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyPrivateDnsNameOptionsRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    instanceId: InstanceId,
    privateDnsHostnameType: Optional[zio.aws.ec2.model.HostnameType] =
      Optional.Absent,
    enableResourceNameDnsARecord: Optional[Boolean] = Optional.Absent,
    enableResourceNameDnsAAAARecord: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest = {
    import ModifyPrivateDnsNameOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .instanceId(InstanceId.unwrap(instanceId): java.lang.String)
      .optionallyWith(privateDnsHostnameType.map(value => value.unwrap))(
        _.privateDnsHostnameType
      )
      .optionallyWith(
        enableResourceNameDnsARecord.map(value => value: java.lang.Boolean)
      )(_.enableResourceNameDnsARecord)
      .optionallyWith(
        enableResourceNameDnsAAAARecord.map(value => value: java.lang.Boolean)
      )(_.enableResourceNameDnsAAAARecord)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest.ReadOnly =
    zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest.wrap(buildAwsValue())
}
object ModifyPrivateDnsNameOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest =
      zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest(
        dryRun.map(value => value),
        instanceId,
        privateDnsHostnameType.map(value => value),
        enableResourceNameDnsARecord.map(value => value),
        enableResourceNameDnsAAAARecord.map(value => value)
      )
    def dryRun: Optional[Boolean]
    def instanceId: InstanceId
    def privateDnsHostnameType: Optional[zio.aws.ec2.model.HostnameType]
    def enableResourceNameDnsARecord: Optional[Boolean]
    def enableResourceNameDnsAAAARecord: Optional[Boolean]
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getInstanceId: ZIO[Any, Nothing, InstanceId] = ZIO.succeed(instanceId)
    def getPrivateDnsHostnameType
        : ZIO[Any, AwsError, zio.aws.ec2.model.HostnameType] = AwsError
      .unwrapOptionField("privateDnsHostnameType", privateDnsHostnameType)
    def getEnableResourceNameDnsARecord: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "enableResourceNameDnsARecord",
        enableResourceNameDnsARecord
      )
    def getEnableResourceNameDnsAAAARecord: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "enableResourceNameDnsAAAARecord",
        enableResourceNameDnsAAAARecord
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest
  ) extends zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val instanceId: InstanceId =
      zio.aws.ec2.model.primitives.InstanceId(impl.instanceId())
    override val privateDnsHostnameType
        : Optional[zio.aws.ec2.model.HostnameType] = zio.aws.core.internal
      .optionalFromNullable(impl.privateDnsHostnameType())
      .map(value => zio.aws.ec2.model.HostnameType.wrap(value))
    override val enableResourceNameDnsARecord: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enableResourceNameDnsARecord())
        .map(value => value: Boolean)
    override val enableResourceNameDnsAAAARecord: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enableResourceNameDnsAAAARecord())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyPrivateDnsNameOptionsRequest
  ): zio.aws.ec2.model.ModifyPrivateDnsNameOptionsRequest.ReadOnly =
    new Wrapper(impl)
}
